import {
  passwordInput,
  passwordConfirmInput,
  passwordCheck,
} from "./domelements";

const [
  passwordLength,
  passwordLowercase,
  passwordUppercase,
  passwordNumber,
  passwordSpecial,
  passwordMatch,
] = passwordCheck.children;

function checkPasswordMatch() {
  if (
    passwordInput.value !== passwordConfirmInput.value ||
    passwordInput.value === ""
  ) {
    passwordMatch.style.backgroundColor = "";
    passwordConfirmInput.setCustomValidity("Passwords don't match");
    return false;
  }
  passwordMatch.style.backgroundColor = "#4b4";
  passwordConfirmInput.setCustomValidity("");
  return true;
}

function checkPasswordRequirement(regex, requirementElement) {
  if (passwordInput.value.search(regex) >= 0) {
    requirementElement.style.backgroundColor = "#4b4";
    return true;
  }
  requirementElement.style.backgroundColor = "";
  return false;
}

function checkPasswordValidity() {
  const length = passwordInput.value.length >= 8;
  if (length) {
    passwordLength.style.backgroundColor = "#4b4";
  } else {
    passwordLength.style.backgroundColor = "";
  }
  const lowercase = checkPasswordRequirement(/[a-z]/, passwordLowercase);
  const uppercase = checkPasswordRequirement(/[A-Z]/, passwordUppercase);
  const number = checkPasswordRequirement(/\d/, passwordNumber);
  const special = checkPasswordRequirement(/[#?!@$%^&*-]/, passwordSpecial);
  const suitsRequirements =
    length && lowercase && uppercase && number && special;
  if (suitsRequirements) {
    passwordInput.setCustomValidity("");
  } else {
    passwordInput.setCustomValidity("Password does not meet requirements");
  }
  return suitsRequirements;
}

export { checkPasswordValidity, checkPasswordMatch };
